var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import * as React from "react";
import * as classNames from "classnames";
import * as tabbable from "tabbable";
import { Key } from "ts-keycode-enum";
export class Dialog extends React.Component {
    constructor() {
        super(...arguments);
        this.setDialogRef = (ref) => {
            this.dialogRef = ref;
        };
        this.setFocusIfVisible = () => {
            // Needed when the root level element is animated
            if (this.props.isVisible === true) {
                this.dialogRef.focus();
            }
        };
        this.onKeyDown = (event) => {
            if (this.handleEscapeClick(event)) {
                return;
            }
            if (this.handleTabClick(event)) {
                return;
            }
        };
        this.onDialogClick = (event) => {
            event.preventDefault();
            event.stopPropagation();
            this.dialogRef.focus();
        };
        this.onBackgroundClick = () => {
            if (this.props.onBackgroundClick) {
                this.props.onBackgroundClick();
            }
        };
    }
    componentDidMount() {
        if (this.props.isVisible === true) {
            this.dialogRef.focus();
        }
    }
    componentDidUpdate(oldProps) {
        // Needed for when the root level element is not animated
        if (this.props.isVisible === true &&
            this.props.isVisible !== oldProps.isVisible) {
            this.dialogRef.scrollTop = 0;
            this.dialogRef.focus();
        }
    }
    render() {
        let _a = this.props, { isBaseStylesDisabled, onBackgroundClick, isVisible, className } = _a, htmlProps = __rest(_a, ["isBaseStylesDisabled", "onBackgroundClick", "isVisible", "className"]);
        className = classNames({ "sci-react-dialog": isBaseStylesDisabled !== true }, className, { "visible": this.props.isVisible });
        return (React.createElement("div", Object.assign({}, htmlProps, { className: className, onAnimationEnd: this.setFocusIfVisible, onTransitionEnd: this.setFocusIfVisible }),
            React.createElement("div", { className: "overlay", onClick: this.onBackgroundClick },
                React.createElement("div", { ref: this.setDialogRef, role: "dialog", tabIndex: 1, className: "dialog", onClick: this.onDialogClick, onKeyDown: this.onKeyDown }, this.props.children))));
    }
    handleEscapeClick(event) {
        if (!event.isDefaultPrevented() && event.keyCode &&
            event.keyCode === Key.Escape) {
            event.preventDefault();
            this.onBackgroundClick();
            return true;
        }
        else {
            return false;
        }
    }
    handleTabClick(event) {
        if (event.isDefaultPrevented() || event.keyCode == null &&
            event.keyCode !== Key.Tab) {
            return false;
        }
        let tabbableElements = tabbable(this.dialogRef);
        let first = tabbableElements[0];
        let last = tabbableElements[tabbableElements.length - 1];
        if (first === undefined) {
            // This has no tabbable elements, set focus back on the dialog itself
            this.dialogRef.focus();
            event.preventDefault();
        }
        else if (document.activeElement === this.dialogRef || event.target === last && !event.shiftKey) {
            first.focus();
            event.preventDefault();
        }
        else if (event.target === first && event.shiftKey) {
            last.focus();
            event.preventDefault();
        }
        return true;
    }
}
//# sourceMappingURL=component.js.map